# DataFrame Download Button Demo

This application demonstrates a custom Gradio component that allows downloading a Pandas DataFrame
as a CSV file, directly from the client-side, without saving the file on the server.

1. Adjust the slider to set the number of rows for the DataFrame.
2. Click 'Generate Data' to create the DataFrame and display it.
3. The 'Download DataFrame' button will become active.
4. Click 'Download DataFrame' to download the data as a CSV file.
